FROM debian/eol:stretch-slim
MAINTAINER Le Filament <https://le-filament.com>

ENV APT_DEPS='build-essential libldap2-dev libsasl2-dev python3-dev python3-wheel' \
    LANG=C.UTF-8 \
    LC_ALL=C.UTF-8 \
    PGDATABASE=odoo

RUN set -x; \
  sed -E -i \
    -e 's/deb.debian.org/archive.debian.org/g' \
    -e 's!(^deb http://archive.debian.org/debian stretch-updates main$)!#\1!' \
    /etc/apt/sources.list \
  && apt-get update \
  && apt-get install -y --no-install-recommends \
    apt-transport-https \
    ca-certificates \
    curl \
    fontconfig \
    git \
    gnupg \
    libssl1.0-dev \
    libx11-6 \
    libxcb1 \
    libxext6 \
    libxrender1 \
    node-less \
    openssh-client \
    python3-pip \
    python3-pyldap \
    python3-qrcode \
    python3-renderpm \
    python3-setuptools \
    python3-vobject \
    python3-watchdog \
    xfonts-75dpi \
    xfonts-base \
    xz-utils \
  && echo 'deb http://apt-archive.postgresql.org/pub/repos/apt/ stretch-pgdg main' >> /etc/apt/sources.list.d/postgresql.list \
  && curl -SL https://www.postgresql.org/media/keys/ACCC4CF8.asc | apt-key add - \
  && curl -o wkhtmltox.deb -SL https://github.com/wkhtmltopdf/wkhtmltopdf/releases/download/0.12.5/wkhtmltox_0.12.5-1.stretch_amd64.deb \
  && echo '7e35a63f9db14f93ec7feeb0fce76b30c08f2057 wkhtmltox.deb' | sha1sum -c - \
  && apt-get update \
  && apt-get install -y --no-install-recommends ./wkhtmltox.deb \
  && apt-get install -y --no-install-recommends postgresql-client \
  && apt-get install -y --no-install-recommends ${APT_DEPS} \
  && curl https://bootstrap.pypa.io/pip/3.5/get-pip.py | python3 /dev/stdin \
  && pip install -I -r https://raw.githubusercontent.com/OCA/OCB/12.0/requirements.txt \
  && pip install 'simplejson' 'WTForms' 'zxcvbn' 'phonenumbers' 'Werkzeug==0.14.1' \
  && apt-get -y purge ${APT_DEPS} \
  && apt-get -y autoremove \
  && rm -rf /var/lib/apt/lists/* wkhtmltox.deb

ARG SAVE_COMMITS_DIR='/opt/odoo_commits/'
ENV SAVE_COMMITS_DIR=$SAVE_COMMITS_DIR

# Add Git Known Hosts
COPY ./ssh_known_git_hosts /root/.ssh/known_hosts

# Install Odoo and remove not French translations and .git directory to limit amount of data used by container
ARG SAVE_COMMITS_FILENAME='ocb'
RUN set -x; \
  repo='https://github.com/OCA/OCB' \
  && useradd --create-home --home-dir /opt/odoo --no-log-init odoo \
  && /bin/bash -c "mkdir -p /opt/odoo/{etc,odoo,additional_addons,private_addons,data,private}" \
  && mkdir /opt/odoo_commits \
  && git clone --single-branch --branch '12.0' --depth 1 "${repo}" /tmp/repo \
    && commit="$(git -C /tmp/repo rev-parse HEAD)" \
    && mv /tmp/repo/* /opt/odoo/odoo/ \
    && echo "${repo};${commit}" > $SAVE_COMMITS_DIR/$SAVE_COMMITS_FILENAME \
  && rm -r /tmp/repo \
  # Only keep French translations.
  && find /opt/odoo/odoo/addons/*/i18n/ /opt/odoo/odoo/odoo/addons/base/i18n/ -type f -not -name 'fr.po' -delete \
  && echo "info: OCB commit:" \
  && cat $SAVE_COMMITS_DIR/$SAVE_COMMITS_FILENAME

# Add script to download Odoo addons.
COPY --chown=root:root --chmod=755 ./get_addons /usr/local/bin

# Install Odoo OCA default dependencies
ARG SAVE_COMMITS_FILENAME='default_addons'
RUN set -x; \
  get_addons 'https://github.com/OCA/account-financial-reporting.git' '12.0' 'additional_addons' \
    account_tax_balance \
  && get_addons 'https://github.com/OCA/account-financial-tools.git' '12.0' 'additional_addons' \
    account_lock_date_update \
  && get_addons 'https://github.com/OCA/account-invoicing.git' '12.0' 'additional_addons' \
    sale_timesheet_invoice_description \
  && get_addons 'https://github.com/OCA/bank-statement-import.git' '12.0' 'additional_addons' \
    account_bank_statement_import_ofx \
  && get_addons 'https://github.com/OCA/knowledge.git' '12.0' 'additional_addons' \
    knowledge \
    document_page \
  && get_addons 'https://github.com/OCA/partner-contact.git' '12.0' 'additional_addons' \
    partner_disable_gravatar \
    partner_firstname \
  && get_addons 'https://github.com/OCA/project.git' '12.0' 'additional_addons' \
    project_category \
    project_status \
    project_task_default_stage \
    project_template \
    project_timeline \
  && get_addons 'https://github.com/OCA/sale-workflow.git' '12.0' 'additional_addons' \
    partner_contact_sale_info_propagation \
    partner_prospect \
  && get_addons 'https://github.com/OCA/server-auth.git' '12.0' 'additional_addons' \
    auth_session_timeout \
    password_security \
  && get_addons 'https://github.com/OCA/server-brand.git' '12.0' 'additional_addons' \
    disable_odoo_online \
    remove_odoo_enterprise \
  && get_addons 'https://github.com/OCA/server-tools.git' '12.0' 'additional_addons' \
    base_search_fuzzy \
    module_change_auto_install \
  && get_addons 'https://github.com/OCA/server-ux.git' '12.0' 'additional_addons' \
    base_technical_features \
    date_range \
    mass_editing \
    mass_operation_abstract \
  && get_addons 'https://github.com/OCA/social.git' '12.0' 'additional_addons' \
    base_search_mail_content \
    mail_debrand \
    mail_tracking \
  && get_addons 'https://github.com/OCA/web.git' '12.0' 'additional_addons' \
    web_environment_ribbon \
    web_export_view \
    web_no_bubble \
    web_responsive \
    web_timeline \
   # Only keep French translations.
  && find /opt/odoo/additional_addons/*/i18n/ -type f -not -name 'fr.po' -delete \
  # Install Le Filament default addons.
  && get_addons 'https://sources.le-filament.com/lefilament/lefilament_release_agent.git' '12.0' 'private_addons/lefilament_release_agent' \
  && echo "info: default addon commits:" \
  && cat $SAVE_COMMITS_DIR/$SAVE_COMMITS_FILENAME

# Copy entrypoint script and Odoo configuration file
COPY ./entrypoint.sh /
COPY ./odoo.conf /opt/odoo/etc/odoo.conf
RUN chown -R odoo:odoo /opt/odoo

# Mount /opt/odoo/data to allow restoring filestore
VOLUME ["/opt/odoo/data/"]

# Expose Odoo services
EXPOSE 8069

# Set default user when running the container
USER odoo

# Start
ENTRYPOINT ["/entrypoint.sh"]
CMD ["odoo"]

# Metadata
LABEL org.label-schema.schema-version="12.0" \
      org.label-schema.vendor=LeFilament \
      org.label-schema.license=Apache-2.0 \
      org.label-schema.vcs-url="https://sources.le-filament.com/lefilament/odoo_docker"
